==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/cube/controller/CubeDataPermissionController.java <==
/**
 * 
 */
package org.springblade.cube.controller;

import java.util.ArrayList;
import java.util.Base64;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.api.R;
import org.springblade.cube.model.CubeData;
import org.springblade.cube.model.CubeDataPermission;
import org.springblade.cube.service.CubeDataPermissionService;
import org.springblade.cube.service.CubeDataService;
import org.springblade.report.entity.ReportDatasource;
import org.springblade.report.enums.DsTypeEnum;
import org.springblade.report.service.IReportDatasourceService;
import org.springblade.visual.dto.ComponentFilter;
import org.springblade.visual.dto.ComponentFilterRelation;
import org.springblade.visual.dto.PreviewBaseDto;
import org.springblade.visual.service.QuerySqlService;
import org.springblade.visual.utils.Tuple2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("/cubeDataPerm")
@Api(value = "数据集权限组接口", tags = "数据集权限组相关接口")
public class CubeDataPermissionController extends BladeController {

	@Autowired
	private CubeDataPermissionService cubeDataPermissionService;
	
	@Autowired
	private QuerySqlService querySqlService;
	
	@Autowired
	private IReportDatasourceService reportDatasourceService;

	@Autowired
	private CubeDataService cubeDataService;
	
	/**
	 * 
	 * @param query
	 * @param name
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation(value = "根据数据集ID查询列表")
	public R<List<CubeDataPermission>> list(@RequestParam Integer cubeDataId){
		return R.data(cubeDataPermissionService.list(Wrappers.<CubeDataPermission>lambdaQuery().eq(CubeDataPermission::getCubeDataId, cubeDataId)));
	}
	
	/**
	 * 
	 * @return
	 */
	@PostMapping("/delete")
	@ApiOperation(value = "删除数据")
	public R<String> delete(@RequestParam Integer cubePermId){
		return R.status(cubeDataPermissionService.removeById(cubePermId));
	}
	
	/**
	 * 
	 * @return
	 */
	@PostMapping("/submit")
	@ApiOperation(value = "添加或修改一个权限组过滤器", notes = "添加过滤器时，页面端默认选中该数据集")
	public R<String> doSubmit(@RequestBody String value) throws Exception{
		String decoderStr = new String(Base64.getDecoder().decode(value), "utf-8");
		CubeDataPermission cubeDataPerm = JSON.parseObject(decoderStr, CubeDataPermission.class);
		if(cubeDataPerm.getId() == null) {
			//如果没有传递ID，有可能从权限组侧编辑入口进入，需要判断是否已存在
			CubeDataPermission dbCubeDataPermission = cubeDataPermissionService.getOne(Wrappers.<CubeDataPermission>lambdaQuery()
					.eq(CubeDataPermission::getCubeDataId, cubeDataPerm.getCubeDataId())
					.eq(CubeDataPermission::getDataPermId, cubeDataPerm.getDataPermId()).last("limit 1"));
			if(dbCubeDataPermission != null) {
				cubeDataPerm.setId(dbCubeDataPermission.getId());
			}else {
				cubeDataPerm.setCreateUserId(getUser().getUserId());
				cubeDataPerm.setCreateTime(new Date());
			}
		}
		//查询数据集
		CubeData cubeData = cubeDataService.getById(cubeDataPerm.getCubeDataId());
		if(cubeData == null) {
			return R.fail("数据集不存在");
		}
		//查询数据源
		ReportDatasource reportDatasource = reportDatasourceService.getById(cubeData.getDatasourceId());
		if (reportDatasource == null) {
			return R.fail("数据集所在数据源不存在");
		}
		DsTypeEnum dsTypeEnum = DsTypeEnum.resolve(reportDatasource.getDsType());
		PreviewBaseDto previewDto = JSON.parseObject(cubeDataPerm.getFilterJson(), PreviewBaseDto.class);
		//解析SQL
		Tuple2<String, String> whereHavingSqlTuple = querySqlService.parseFilters(JSON.parseArray(previewDto.getFilterList(), ComponentFilter.class), 
				JSON.parseObject(previewDto.getFilterRelation(), ComponentFilterRelation.class), dsTypeEnum);
		cubeDataPerm.setFilterSql(whereHavingSqlTuple.getT1());
		if(cubeData.getPublicStatus() == 1) { //如果是公开状态，更新为非公开[否则权限组无效]
			cubeDataService.update(Wrappers.<CubeData>lambdaUpdate().set(CubeData::getPublicStatus, 0).eq(CubeData::getId, cubeDataPerm.getCubeDataId()));
		}
		return R.status(cubeDataPermissionService.saveOrUpdate(cubeDataPerm));
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param visualClassifyId
	 * @return
	 */
	@GetMapping("/cubeIdList")
	@ApiOperation(value = "根据权限组ID和分类ID查询数据集ID列表")
	public R<List<Integer>> cubeIdList(@RequestParam Integer dataPermId, @RequestParam Integer cubeWorkspaceId){
		List<CubeDataPermission> dataList = cubeDataPermissionService.selectListByDataPermIdAndWorkspaceId(dataPermId, cubeWorkspaceId);
		return R.data(CollectionUtil.isNotEmpty(dataList) ? dataList.stream().map(CubeDataPermission::getCubeDataId).collect(Collectors.toList()) : new ArrayList<>());
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param cubeWorkspaceId
	 * @param cubeDataId
	 * @return
	 */
	@GetMapping("/info")
	@ApiOperation(value = "权限组ID和分类ID和数据集ID查询详情")
	public R<CubeDataPermission> info(@RequestParam Integer dataPermId, @RequestParam Integer cubeDataId){
		return R.data(cubeDataPermissionService.getOne(Wrappers.<CubeDataPermission>lambdaQuery()
					.eq(CubeDataPermission::getCubeDataId, cubeDataId)
					.eq(CubeDataPermission::getDataPermId, dataPermId).last("limit 1")));
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param cubeWorkspaceId
	 * @param dataIdList
	 * @return
	 */
	@PostMapping("/batch-submit/{dataPermId}/{cubeWorkspaceId}")
	@ApiOperation(value = "批量选中多个数据集", notes = "权限组设置-数据集入口")
	public R<Integer> doBatchSubmit(@PathVariable Integer dataPermId, @PathVariable Integer cubeWorkspaceId, @RequestBody List<Integer> dataIdList){
		return R.status(cubeDataPermissionService.doBatchSubmit(dataPermId, cubeWorkspaceId, getUser().getUserId(), dataIdList));
	}
}

==> v1.1.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/cube/controller/CubeDataPermissionController.java <==
/**
 * 
 */
package org.springblade.cube.controller;

import java.util.ArrayList;
import java.util.Base64;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.api.R;
import org.springblade.cube.model.CubeData;
import org.springblade.cube.model.CubeDataPermission;
import org.springblade.cube.service.CubeDataPermissionService;
import org.springblade.cube.service.CubeDataService;
import org.springblade.report.entity.ReportDatasource;
import org.springblade.report.enums.DsTypeEnum;
import org.springblade.report.service.IReportDatasourceService;
import org.springblade.visual.dto.ComponentFilter;
import org.springblade.visual.dto.ComponentFilterRelation;
import org.springblade.visual.dto.PreviewBaseDto;
import org.springblade.visual.service.QuerySqlService;
import org.springblade.visual.utils.Tuple2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("/cubeDataPerm")
@Api(value = "数据集权限组接口", tags = "数据集权限组相关接口")
public class CubeDataPermissionController extends BladeController {

	@Autowired
	private CubeDataPermissionService cubeDataPermissionService;
	
	@Autowired
	private QuerySqlService querySqlService;
	
	@Autowired
	private IReportDatasourceService reportDatasourceService;

	@Autowired
	private CubeDataService cubeDataService;
	
	/**
	 * 
	 * @param query
	 * @param name
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation(value = "根据数据集ID查询列表")
	public R<List<CubeDataPermission>> list(@RequestParam Integer cubeDataId){
		return R.data(cubeDataPermissionService.list(Wrappers.<CubeDataPermission>lambdaQuery().eq(CubeDataPermission::getCubeDataId, cubeDataId)));
	}
	
	/**
	 * 
	 * @return
	 */
	@PostMapping("/delete")
	@ApiOperation(value = "删除数据")
	public R<String> delete(@RequestParam Integer cubePermId){
		return R.status(cubeDataPermissionService.removeById(cubePermId));
	}
	
	/**
	 * 
	 * @return
	 */
	@PostMapping("/submit")
	@ApiOperation(value = "添加或修改一个权限组过滤器", notes = "添加过滤器时，页面端默认选中该数据集")
	public R<String> doSubmit(@RequestBody String value) throws Exception{
		String decoderStr = new String(Base64.getDecoder().decode(value), "utf-8");
		CubeDataPermission cubeDataPerm = JSON.parseObject(decoderStr, CubeDataPermission.class);
		if(cubeDataPerm.getId() == null) {
			//如果没有传递ID，有可能从权限组侧编辑入口进入，需要判断是否已存在
			CubeDataPermission dbCubeDataPermission = cubeDataPermissionService.getOne(Wrappers.<CubeDataPermission>lambdaQuery()
					.eq(CubeDataPermission::getCubeDataId, cubeDataPerm.getCubeDataId())
					.eq(CubeDataPermission::getDataPermId, cubeDataPerm.getDataPermId()).last("limit 1"));
			if(dbCubeDataPermission != null) {
				cubeDataPerm.setId(dbCubeDataPermission.getId());
			}else {
				cubeDataPerm.setCreateUserId(getUser().getUserId());
				cubeDataPerm.setCreateTime(new Date());
			}
		}
		//查询数据集
		CubeData cubeData = cubeDataService.getById(cubeDataPerm.getCubeDataId());
		if(cubeData == null) {
			return R.fail("数据集不存在");
		}
		//查询数据源
		ReportDatasource reportDatasource = reportDatasourceService.getById(cubeData.getDatasourceId());
		if (reportDatasource == null) {
			return R.fail("数据集所在数据源不存在");
		}
		DsTypeEnum dsTypeEnum = DsTypeEnum.resolve(reportDatasource.getDsType());
		PreviewBaseDto previewDto = JSON.parseObject(cubeDataPerm.getFilterJson(), PreviewBaseDto.class);
		//解析SQL
		Tuple2<String, String> whereHavingSqlTuple = querySqlService.parseFilters(JSON.parseArray(previewDto.getFilterList(), ComponentFilter.class), 
				JSON.parseObject(previewDto.getFilterRelation(), ComponentFilterRelation.class), dsTypeEnum, previewDto.getExtraParams());
		cubeDataPerm.setFilterSql(whereHavingSqlTuple.getT1());
		if(cubeData.getPublicStatus() == 1) { //如果是公开状态，更新为非公开[否则权限组无效]
			cubeDataService.update(Wrappers.<CubeData>lambdaUpdate().set(CubeData::getPublicStatus, 0).eq(CubeData::getId, cubeDataPerm.getCubeDataId()));
		}
		return R.status(cubeDataPermissionService.saveOrUpdate(cubeDataPerm));
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param visualClassifyId
	 * @return
	 */
	@GetMapping("/cubeIdList")
	@ApiOperation(value = "根据权限组ID和分类ID查询数据集ID列表")
	public R<List<Integer>> cubeIdList(@RequestParam Integer dataPermId, @RequestParam Integer cubeWorkspaceId){
		List<CubeDataPermission> dataList = cubeDataPermissionService.selectListByDataPermIdAndWorkspaceId(dataPermId, cubeWorkspaceId);
		return R.data(CollectionUtil.isNotEmpty(dataList) ? dataList.stream().map(CubeDataPermission::getCubeDataId).collect(Collectors.toList()) : new ArrayList<>());
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param cubeWorkspaceId
	 * @param cubeDataId
	 * @return
	 */
	@GetMapping("/info")
	@ApiOperation(value = "权限组ID和分类ID和数据集ID查询详情")
	public R<CubeDataPermission> info(@RequestParam Integer dataPermId, @RequestParam Integer cubeDataId){
		return R.data(cubeDataPermissionService.getOne(Wrappers.<CubeDataPermission>lambdaQuery()
					.eq(CubeDataPermission::getCubeDataId, cubeDataId)
					.eq(CubeDataPermission::getDataPermId, dataPermId).last("limit 1")));
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param cubeWorkspaceId
	 * @param dataIdList
	 * @return
	 */
	@PostMapping("/batch-submit/{dataPermId}/{cubeWorkspaceId}")
	@ApiOperation(value = "批量选中多个数据集", notes = "权限组设置-数据集入口")
	public R<Integer> doBatchSubmit(@PathVariable Integer dataPermId, @PathVariable Integer cubeWorkspaceId, @RequestBody List<Integer> dataIdList){
		return R.status(cubeDataPermissionService.doBatchSubmit(dataPermId, cubeWorkspaceId, getUser().getUserId(), dataIdList));
	}
}
